#include "CHMpreCompHead.h"
#pragma hdrstop

#include <CHM/CHMtableDef.h>
#include <CHM/CHMtableDefClass.h>
#include <assert.h>

//---------------------------------------------------------------------------------
// implementation private class
class CHMtableDefinitionPrivate
{
public:
   CHMtableDefinitionPrivate(CHMtableDefinitionHandle Handle);
   ~CHMtableDefinitionPrivate();

   CHMtableDefinitionHandle  TableDefHandle;
};

CHMtableDefinitionPrivate::CHMtableDefinitionPrivate
(
   CHMtableDefinitionHandle Handle
) : TableDefHandle(Handle) 
{
   assert(Handle != NULL);
}

CHMtableDefinitionPrivate::~CHMtableDefinitionPrivate()
{
}

//---------------------------------------------------------------------------------
CHMtableDefinition::CHMtableDefinition
(
   CHMtableDefinitionHandle Handle
) : pMember(NULL)
{  
   pMember = new CHMtableDefinitionPrivate(Handle);
}

CHMtableDefinition::CHMtableDefinition() : pMember(NULL)
{
   pMember = new CHMtableDefinitionPrivate(NULL);
}

CHMtableDefinition::~CHMtableDefinition()
{
   delete pMember;
}

const char* CHMtableDefinition::TableName() const
{
   char* pName;
   CHM_CHECK_CALL(CHMtableDefinitionGetTableName(GetTableDefHandle(), &pName));
   return pName;
}

CHMtableHandle CHMtableDefinition::GetTableDefHandle() const
{
   return pMember->TableDefHandle; 
}

CHMboolean CHMtableDefinition::IsKey(size_t ColumnIndex) const
{
   size_t IsKey = 0;
   CHM_CHECK_CALL(CHMtableDefinitionGetColumnIsKey(GetTableDefHandle(), ColumnIndex, &IsKey));
   return IsKey!=0;
}

size_t CHMtableDefinition::CountOfColumn() const
{
   size_t Count;
   CHM_CHECK_CALL(CHMtableDefinitionGetCountOfColumn(GetTableDefHandle(), &Count));
   return Count;
}

const char* CHMtableDefinition::ColumnName(size_t ColumnIndex) const
{
   char* pColumnName;
   CHM_CHECK_CALL(CHMtableDefinitionGetColumnName(GetTableDefHandle(), ColumnIndex, &pColumnName));
   return pColumnName;
}

CHMdataType CHMtableDefinition::ColumnType(size_t ColumnIndex) const
{
   CHMdataType DataType;
   CHM_CHECK_CALL(CHMtableDefinitionGetColumnType(GetTableDefHandle(), ColumnIndex, &DataType));
   return DataType;
}

CHMstring CHMtableDefinition::Dump() const
{
   CHMstring Dump;
   CHMchar* pBuffer;
   
   CHM_CHECK_CALL(CHMtableDumpT(GetTableDefHandle(), &pBuffer));
   Dump = pBuffer;
   CHM_CHECK_CALL(CHMtableFreeBufferT(&pBuffer));

   return Dump;
}
